@@ -14,6 +14,7 @@ import _damo_fs
 import _damo_subproc
 import _damon_dbgfs
 import _damon_features
+import _damon_modules
 import _damon_sysfs
 import damo_version
 
@@ -77,7 +78,6 @@ class SystemInfo:
         avail_damon_features = []
         if 'avail_damon_features' in kvpairs:
             avail_damon_features = kvpairs['avail_damon_features']
-        damon_modules = []
         sysfs_path = None
         if 'sysfs_path' in kvpairs:
             sysfs_path = kvpairs['sysfs_path']
@@ -119,6 +119,7 @@ class SystemInfo:
         avail_features = {f.name for f in self.avail_damon_features}
         if len(avail_features) == 0:
             return '<5.15', None
+        append_plus = False
         for feature in reversed(_damon_features.features_list):
             if feature.name in avail_features:
                 if feature.upstreamed_version in ['none', 'unknown']:
@@ -154,18 +155,6 @@ def valid_cached_sysinfo(sysinfo, damo_version_, kernel_version):
         return False
     return True
 
-def set_sysinfo_from_cache():
-    sysinfo, err = read_sysinfo_file()
-    if err is not None:
-        return 'reading saved sysinfo fail (%s)' % err
-    damo_version_ = damo_version.get_real_version()
-    kernel_version = subprocess.check_output(['uname', '-r']).decode().strip()
-    if not valid_cached_sysinfo(sysinfo, damo_version_, kernel_version):
-        return 'cached sysinfo cannot be used'
-    global system_info
-    system_info = sysinfo
-    return None
-
 def avail_features_on(damon_fs):
     if not damon_fs.supported():
         return [], None
@@ -193,9 +182,6 @@ def get_damon_tracepoints():
         return None, 'available tracepoints reading fail'
     return points, None
 
-def damon_feature_of_name(name):
-    return [f for f in _damon_features.features_list if f.name == name][0]
-
 tracepoint_to_feature_name_map = {
         'damon:damon_aggregated': 'trace/damon_aggregated',
         'damon:damos_before_apply': 'trace/damos_before_apply',
@@ -213,31 +199,26 @@ def get_avail_damon_trace_features():
         return None, err
     for tracepoint, feature_name in tracepoint_to_feature_name_map.items():
         if tracepoint in tracepoints:
-            features.append(damon_feature_of_name(feature_name))
+            features.append(_damon_features.feature_of_name(feature_name))
     return features, err
 
-def get_avail_damon_modules():
+def get_avail_damon_interface_features():
     features = []
 
     if _damon_dbgfs.supported():
-        features.append(damon_feature_of_name('module/damon_debugfs'))
+        features.append(_damon_features.feature_of_name(
+            'interface/damon_debugfs'))
 
     sysfs_path = _damo_fs.dev_mount_point('sysfs')
     if sysfs_path is None:
         return features
 
     if _damon_sysfs.supported():
-        features.append(damon_feature_of_name('module/damon_sysfs'))
+        features.append(_damon_features.feature_of_name(
+            'interface/damon_sysfs'))
+
+    features += _damon_modules.get_avail_interface_features()
 
-    mod_path = os.path.join(sysfs_path, 'module')
-    if not os.path.isdir(mod_path):
-        return features
-    if os.path.isdir(os.path.join(mod_path, 'damon_reclaim')):
-        features.append(damon_feature_of_name('module/damon_reclaim'))
-    if os.path.isdir(os.path.join(mod_path, 'damon_lru_sort')):
-        features.append(damon_feature_of_name('module/damon_lru_sort'))
-    if os.path.isdir(os.path.join(mod_path, 'damon_stat')):
-        features.append(damon_feature_of_name('module/damon_stat'))
     return features
 
 def get_trace_cmd_version():
@@ -293,8 +274,8 @@ def get_sysinfo_from_scratch():
         return None, 'trace feature check fail (%s)' % err
     avail_damon_features += avail_damon_trace_features
 
-    avail_damon_modules = get_avail_damon_modules()
-    avail_damon_features += avail_damon_modules
+    avail_damon_features += get_avail_damon_interface_features()
+    avail_damon_features += _damon_modules.get_avail_features()
 
     sysinfo = SystemInfo(
             damo_version=damo_version_,
@@ -331,15 +312,21 @@ def update_cached_info(cached_info):
         if err is not None:
             return None, 'damon sysfs features update fail (%s)' % err
 
-        avail_damon_modules = get_avail_damon_modules()
-
         avail_damon_features = []
         for f in cached_info.avail_damon_features:
-            if f.name.startswith('sysfs/') or f.name.startswith('module/'):
+            interfaces_to_recheck = ['sysfs', 'interface', 'reclaim',
+                                     'lru_sort', 'stat']
+            skip = False
+            for interface in interfaces_to_recheck:
+                if f.name.startswith('%s/' % interface):
+                    skip = True
+                    break
+            if skip:
                 continue
             avail_damon_features.append(f)
         avail_damon_features += avail_damon_sysfs_feastures
-        avail_damon_features += avail_damon_modules
+        avail_damon_features += get_avail_damon_interface_features()
+        avail_damon_features += _damon_modules.get_avail_features()
         cached_info.avail_damon_features = avail_damon_features
 
     tracefs_path = _damo_fs.dev_mount_point('tracefs')
@@ -423,6 +410,13 @@ def get_sysinfo():
             return None, err
     return system_info, None
 
+def get_sysinfo_or_panic():
+    sysinfo, err = get_sysinfo()
+    if err is not None:
+        raise Exception('[PANIC] get_sysinfo() fail (%s)' % err)
+        exit(1)
+    return sysinfo
+
 def damon_tracepoint_available(tracepoint):
     sysinfo, err = get_sysinfo()
     if err is not None:
