@@ -546,7 +546,7 @@ class DamonTarget:
         if self.pid is not None:
             lines.append('pid: %s' % self.pid)
         if self.obsolete is True:
-            line.sappend('(obsolete)')
+            lines.append('(obsolete)')
         for region in self.regions:
             lines.append('region %s' % region.to_str(raw))
         return '\n'.join(lines)
@@ -1377,7 +1377,7 @@ class DamonCtx:
         if sample_control is None:
             sample_control = DamonSampleControl()
         self.sample_control = sample_control
-        self.schemes = schemes if schemes is not None else Damos()
+        self.schemes = schemes if schemes is not None else []
         for scheme in self.schemes:
             scheme.context = self
 
@@ -1461,6 +1461,7 @@ class Kdamond:
     pid = None
     refresh_ms = None
     contexts = None
+    interface = None    # interface that was used for creating this kdamond
 
     def __init__(self, state, pid, contexts, refresh_ms=0):
         self.state = state
@@ -1562,16 +1563,30 @@ def set_damon_interface(damon_interface):
         return 'DAMON interface (%s) not supported' % damon_interface
     return None
 
+damon_unavail_msg = '''
+DAMON is not available on this system.  Ask help to your sysadmin or DAMON
+community.
+
+To ask help to DAMON community, you can
+- send a mail to the mailing list (damon@lists.linux.dev),
+- open a damo GitHub issue (https://github.com/damonitor/damo/issues), or
+- send a mail to DAMON maintainer: sj@kernel.org
+'''
+
 def initialize(damon_interface, debug_damon, load_sysinfo):
-    err = set_damon_interface(damon_interface)
-    if err is not None:
-        return err
     if debug_damon:
         _damo_fs.debug_print_ops(True)
     if load_sysinfo:
-        err = _damo_sysinfo.load_sysinfo()
+        sysinfo, err = _damo_sysinfo.get_sysinfo()
         if err is not None:
             return err
+        version, err = sysinfo.infer_damon_version()
+        if version == '<5.15':
+            return damon_unavail_msg
+    err = set_damon_interface(damon_interface)
+    if err is not None:
+        return err
+
     return None
 
 initialized = False
@@ -1812,7 +1827,7 @@ def add_commit_vaddr_child_targets(kdamonds):
         idx = 0
         for kd in kdamonds:
             for ctx in kd.contexts:
-                ctx.targets = old_targets[idx]
+                ctx.targets = old_targets_list[idx]
                 idx += 1
         return 'commit failed (%s)' % err
 
